from collections import defaultdict

from dungeonsheets import features, spells, weapons

# Custom Classes
